"""adripy is a set of python tools for manipulating MSC Adams Drill files and data.

Available subpackages
---------------------
tiem_orbit
    Classes representing adams drill objects. (Events, Strings, Stabilizers, ect.)

Available modules
-----------------
adripy
    Functions for manipulating MSC Adams Drill files
"""
from .adripy import *
from . import tiem_orbit
